<?php
/**
 * A block interface
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Block extends FrameworkInterface {
	/**
	 * Reads the file header
	 *
	 * @return	void
	 */
	function readFileHeader ();

	/**
	 * Flushes the file header
	 *
	 * @return	void
	 */
	function flushFileHeader ();

	/**
	 * Close a file source and set it's instance to null and the file name
	 * to empty.
	 *
	 * @return	void
	 * @throws	NullPointerException	If the file pointer instance is not set by setPointer()
	 * @throws	InvalidResourceException	If there is being set
	 */
	function closeFile ();

	/**
	 * Determines whether the EOF has been reached
	 *
	 * @return	$isEndOfFileReached		Whether the EOF has been reached
	 */
	function isEndOfFileReached ();

	/**
	 * Getter for file name
	 *
	 * @return	$fileName	The current file name
	 */
	function getFileName ();

	/**
	 * Initializes counter for valid entries, arrays for damaged entries and
	 * an array for gap seek positions. If you call this method on your own,
	 * please re-analyze the file structure. So you are better to call
	 * analyzeFile() instead of this method.
	 *
	 * @return	void
	 */
	function initCountersGapsArray ();

	/**
	 * Getter for header size
	 *
	 * @return	$totalEntries	Size of file header
	 */
	function getHeaderSize ();

	/**
	 * Setter for header size
	 *
	 * @param	$headerSize		Size of file header
	 * @return	void
	 */
	function setHeaderSize ($headerSize);

	/**
	 * Getter for header array
	 *
	 * @return	$totalEntries	Size of file header
	 */
	function getHeader ();

	/**
	 * Setter for header
	 *
	 * @param	$header		Array for a file header
	 * @return	void
	 */
	function setHeader (array $header);

	/**
	 * Updates seekPosition attribute from file to avoid to much access on file.
	 *
	 * @return	void
	 */
	function updateSeekPosition ();

	/**
	 * Getter for total entries
	 *
	 * @return	$totalEntries	Total entries in this file
	 */
	function getCounter ();

	/**
	 * "Getter" for file size
	 *
	 * @return	$fileSize	Size of currently loaded file
	 */
	function getFileSize ();
}

// [EOF]
?>
